@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.06';
+our $VERSION = '1.0';
 
 my $desc = q{Hash key with bareword};
 
@@ -20,7 +20,17 @@ sub violates {
     return if !is_hash_key($elem);
 
     return if is_method_call($elem);
+    return if is_subroutine_name($elem);
     return if is_function_call($elem);
+    return if is_perl_builtin($elem);
+    return if is_perl_global($elem);
+
+    return $self->violation( $desc, ['n/a'], $elem );
+    my $sib = $elem->snext_sibling();
+
+    return unless $sib;
+    return unless $sib->isa('PPI::Token::Number');
+    return unless $sib =~ m/^\d+\z/;
 
     return $self->violation( $desc, ['n/a'], $elem );
 }
@@ -41,33 +51,24 @@ This policy is part of L<Perl::Critic::Itch>.
 
 =head1 VERSION
 
-0.06
+1.0
+
+=head1 SYNOPSIS
+
+Requires backticks on all hash keys barewords
 
 =head1 DESCRIPTION
 
-This Policy forces (single) quotes on all hash keys barewords.
-
-When specifying constant string hash keys, you should use (single) quotes. E.g., $my_hash{'some_key'} 
-
-This is the appropriate choice because it results in consistent formatting and if you forget to use quotes sometimes, you have to remember to add them when your key contains internal hyphens, spaces, or other special characters. 
-
-Quoted keys are also more likely to be syntax-highlighted by your editor.
+When using a bareword as a hash key, we should always use backtips to mode the code more legible.
 
+Things as $my_elem{some_bareword} should be writen as $my_elem{'some_bareword'}
 
 
 =head1 INTERFACE
 
-Standard for a L<Perl::Critic::Policy>.
+Stadard for a L<Perl::Critic::Policy>.
 
-=head1 ACKNOWLEDGMENTS
+=head1 DIAGNOSTICS
 
-Thanks to
-
-=over 4
-
-=item * Jose Carlos Pereira for pointing me in the right direction!
-
-=item * All Perl::Critic::Policy contributors. Their code examples were quite useful.
-
-=back
+None.
 
